#[repr(transparent)]pub struct Utf8(pub Blob);Tuple Fields
0: BlobTrait Implementations
Sourceimpl CandidType for Utf8
impl CandidType for Utf8
Sourceimpl<'de> Deserialize<'de> for Utf8
impl<'de> Deserialize<'de> for Utf8
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FieldTypeMeta for Utf8
impl FieldTypeMeta for Utf8
Sourceconst KIND: FieldKind = Self::__KIND
const KIND: FieldKind = Self::__KIND
Semantic field kind used for runtime planning and validation.
Sourceconst STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
const STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
Persisted decode contract used by row and payload decoding.
Sourceconst NESTED_FIELDS: &'static [FieldModel]
const NESTED_FIELDS: &'static [FieldModel]
Known nested fields for generated structured records.
Sourceimpl PersistedStructuredFieldCodec for Utf8
impl PersistedStructuredFieldCodec for Utf8
Sourcefn encode_persisted_structured_payload(&self) -> Result<Vec<u8>, InternalError>
fn encode_persisted_structured_payload(&self) -> Result<Vec<u8>, InternalError>
Encode this typed structured field into persisted structured payload bytes.
Sourcefn decode_persisted_structured_payload(
bytes: &[u8],
) -> Result<Self, InternalError>
fn decode_persisted_structured_payload( bytes: &[u8], ) -> Result<Self, InternalError>
Decode this typed structured field from persisted structured payload bytes.
Sourceimpl RuntimeValueDecode for Utf8
impl RuntimeValueDecode for Utf8
fn from_value(value: &Value) -> Option<Self>
Sourceimpl RuntimeValueMeta for Utf8
impl RuntimeValueMeta for Utf8
fn kind() -> RuntimeValueKind
Sourceimpl SanitizeAuto for Utf8
impl SanitizeAuto for Utf8
fn sanitize_self(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl SanitizeCustom for Utf8
impl SanitizeCustom for Utf8
fn sanitize_custom(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl ValidateAuto for Utf8
impl ValidateAuto for Utf8
fn validate_self(&self, _ctx: &mut dyn VisitorContext)
Sourceimpl ValidateCustom for Utf8
impl ValidateCustom for Utf8
fn validate_custom(&self, ctx: &mut dyn VisitorContext)
Sourceimpl Visitable for Utf8
impl Visitable for Utf8
fn drive(&self, visitor: &mut dyn VisitorCore)
fn drive_mut(&mut self, visitor: &mut dyn VisitorMutCore)
impl Eq for Utf8
impl StructuralPartialEq for Utf8