#[repr(transparent)]pub struct Field(pub Text);Tuple Fields
0: TextTrait Implementations
Sourceimpl CandidType for Field
impl CandidType for Field
Sourceimpl<'de> Deserialize<'de> for Field
impl<'de> Deserialize<'de> for Field
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FieldTypeMeta for Field
impl FieldTypeMeta for Field
Sourceconst KIND: FieldKind = Self::__KIND
const KIND: FieldKind = Self::__KIND
Semantic field kind used for runtime planning and validation.
Sourceconst STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
const STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
Persisted decode contract used by row and payload decoding.
Sourceconst NESTED_FIELDS: &'static [FieldModel]
const NESTED_FIELDS: &'static [FieldModel]
Known nested fields for generated structured records.
Sourceimpl Ord for Field
impl Ord for Field
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd<Field> for Text
impl PartialOrd<Field> for Text
Sourceimpl PartialOrd<String> for Field
impl PartialOrd<String> for Field
Sourceimpl PartialOrd for Field
impl PartialOrd for Field
Sourceimpl PersistedStructuredFieldCodec for Field
impl PersistedStructuredFieldCodec for Field
Sourcefn encode_persisted_structured_payload(&self) -> Result<Vec<u8>, InternalError>
fn encode_persisted_structured_payload(&self) -> Result<Vec<u8>, InternalError>
Encode this typed structured field into persisted structured payload bytes.
Sourcefn decode_persisted_structured_payload(
bytes: &[u8],
) -> Result<Self, InternalError>
fn decode_persisted_structured_payload( bytes: &[u8], ) -> Result<Self, InternalError>
Decode this typed structured field from persisted structured payload bytes.
Sourceimpl RuntimeValueDecode for Field
impl RuntimeValueDecode for Field
fn from_value(value: &Value) -> Option<Self>
Sourceimpl RuntimeValueMeta for Field
impl RuntimeValueMeta for Field
fn kind() -> RuntimeValueKind
Sourceimpl SanitizeAuto for Field
impl SanitizeAuto for Field
fn sanitize_self(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl SanitizeCustom for Field
impl SanitizeCustom for Field
fn sanitize_custom(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl ValidateAuto for Field
impl ValidateAuto for Field
fn validate_self(&self, ctx: &mut dyn VisitorContext)
Sourceimpl ValidateCustom for Field
impl ValidateCustom for Field
fn validate_custom(&self, _ctx: &mut dyn VisitorContext)
Sourceimpl Visitable for Field
impl Visitable for Field
fn drive(&self, visitor: &mut dyn VisitorCore)
fn drive_mut(&mut self, visitor: &mut dyn VisitorMutCore)
impl Eq for Field
impl StructuralPartialEq for Field