#[repr(transparent)]pub struct Degrees(pub Nat16);Tuple Fields
0: Nat16Trait Implementations
Sourceimpl AddAssign<u16> for Degrees
impl AddAssign<u16> for Degrees
Sourcefn add_assign(&mut self, other: Nat16)
fn add_assign(&mut self, other: Nat16)
Performs the
+= operation. Read moreSourceimpl AddAssign for Degrees
impl AddAssign for Degrees
Sourcefn add_assign(&mut self, other: Degrees)
fn add_assign(&mut self, other: Degrees)
Performs the
+= operation. Read moreSourceimpl CandidType for Degrees
impl CandidType for Degrees
Sourceimpl<'de> Deserialize<'de> for Degrees
impl<'de> Deserialize<'de> for Degrees
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DivAssign<u16> for Degrees
impl DivAssign<u16> for Degrees
Sourcefn div_assign(&mut self, other: Nat16)
fn div_assign(&mut self, other: Nat16)
Performs the
/= operation. Read moreSourceimpl DivAssign for Degrees
impl DivAssign for Degrees
Sourcefn div_assign(&mut self, other: Degrees)
fn div_assign(&mut self, other: Degrees)
Performs the
/= operation. Read moreSourceimpl FieldTypeMeta for Degrees
impl FieldTypeMeta for Degrees
Sourceconst KIND: FieldKind = Self::__KIND
const KIND: FieldKind = Self::__KIND
Semantic field kind used for runtime planning and validation.
Sourceconst STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
const STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
Persisted decode contract used by row and payload decoding.
Sourceconst NESTED_FIELDS: &'static [FieldModel]
const NESTED_FIELDS: &'static [FieldModel]
Known nested fields for generated structured records.
Sourceimpl MulAssign<u16> for Degrees
impl MulAssign<u16> for Degrees
Sourcefn mul_assign(&mut self, other: Nat16)
fn mul_assign(&mut self, other: Nat16)
Performs the
*= operation. Read moreSourceimpl MulAssign for Degrees
impl MulAssign for Degrees
Sourcefn mul_assign(&mut self, other: Degrees)
fn mul_assign(&mut self, other: Degrees)
Performs the
*= operation. Read moreSourceimpl NumericValue for Degrees
impl NumericValue for Degrees
Sourcefn try_to_decimal(&self) -> Option<Decimal>
fn try_to_decimal(&self) -> Option<Decimal>
Convert this value into Decimal for generic numeric handling.
Sourcefn try_from_decimal(value: Decimal) -> Option<Self>
fn try_from_decimal(value: Decimal) -> Option<Self>
Rebuild the value from Decimal after generic numeric handling.
Sourceimpl Ord for Degrees
impl Ord for Degrees
Sourceimpl PartialOrd<Degrees> for Nat16
impl PartialOrd<Degrees> for Nat16
Sourceimpl PartialOrd<u16> for Degrees
impl PartialOrd<u16> for Degrees
Sourceimpl PartialOrd for Degrees
impl PartialOrd for Degrees
Sourceimpl PersistedStructuredFieldCodec for Degrees
impl PersistedStructuredFieldCodec for Degrees
Sourcefn encode_persisted_structured_payload(&self) -> Result<Vec<u8>, InternalError>
fn encode_persisted_structured_payload(&self) -> Result<Vec<u8>, InternalError>
Encode this typed structured field into persisted structured payload bytes.
Sourcefn decode_persisted_structured_payload(
bytes: &[u8],
) -> Result<Self, InternalError>
fn decode_persisted_structured_payload( bytes: &[u8], ) -> Result<Self, InternalError>
Decode this typed structured field from persisted structured payload bytes.
Sourceimpl RuntimeValueDecode for Degrees
impl RuntimeValueDecode for Degrees
fn from_value(value: &Value) -> Option<Self>
Sourceimpl RuntimeValueMeta for Degrees
impl RuntimeValueMeta for Degrees
fn kind() -> RuntimeValueKind
Sourceimpl SanitizeAuto for Degrees
impl SanitizeAuto for Degrees
fn sanitize_self(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl SanitizeCustom for Degrees
impl SanitizeCustom for Degrees
fn sanitize_custom(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl SubAssign<u16> for Degrees
impl SubAssign<u16> for Degrees
Sourcefn sub_assign(&mut self, other: Nat16)
fn sub_assign(&mut self, other: Nat16)
Performs the
-= operation. Read moreSourceimpl SubAssign for Degrees
impl SubAssign for Degrees
Sourcefn sub_assign(&mut self, other: Degrees)
fn sub_assign(&mut self, other: Degrees)
Performs the
-= operation. Read moreSourceimpl ValidateAuto for Degrees
impl ValidateAuto for Degrees
fn validate_self(&self, ctx: &mut dyn VisitorContext)
Sourceimpl ValidateCustom for Degrees
impl ValidateCustom for Degrees
fn validate_custom(&self, _ctx: &mut dyn VisitorContext)
Sourceimpl Visitable for Degrees
impl Visitable for Degrees
fn drive(&self, visitor: &mut dyn VisitorCore)
fn drive_mut(&mut self, visitor: &mut dyn VisitorMutCore)
impl Copy for Degrees
impl Eq for Degrees
impl StructuralPartialEq for Degrees