#[repr(transparent)]pub struct Seconds(pub Nat64);Tuple Fields
0: Nat64Trait Implementations
Sourceimpl AddAssign<u64> for Seconds
impl AddAssign<u64> for Seconds
Sourcefn add_assign(&mut self, other: Nat64)
fn add_assign(&mut self, other: Nat64)
Performs the
+= operation. Read moreSourceimpl AddAssign for Seconds
impl AddAssign for Seconds
Sourcefn add_assign(&mut self, other: Seconds)
fn add_assign(&mut self, other: Seconds)
Performs the
+= operation. Read moreSourceimpl CandidType for Seconds
impl CandidType for Seconds
Sourceimpl<'de> Deserialize<'de> for Seconds
impl<'de> Deserialize<'de> for Seconds
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DivAssign<u64> for Seconds
impl DivAssign<u64> for Seconds
Sourcefn div_assign(&mut self, other: Nat64)
fn div_assign(&mut self, other: Nat64)
Performs the
/= operation. Read moreSourceimpl DivAssign for Seconds
impl DivAssign for Seconds
Sourcefn div_assign(&mut self, other: Seconds)
fn div_assign(&mut self, other: Seconds)
Performs the
/= operation. Read moreSourceimpl FieldTypeMeta for Seconds
impl FieldTypeMeta for Seconds
Sourceconst KIND: FieldKind = Self::__KIND
const KIND: FieldKind = Self::__KIND
Semantic field kind used for runtime planning and validation.
Sourceconst STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
const STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
Persisted decode contract used by row and payload decoding.
Sourceconst NESTED_FIELDS: &'static [FieldModel]
const NESTED_FIELDS: &'static [FieldModel]
Known nested fields for generated structured records.
Sourceimpl MulAssign<u64> for Seconds
impl MulAssign<u64> for Seconds
Sourcefn mul_assign(&mut self, other: Nat64)
fn mul_assign(&mut self, other: Nat64)
Performs the
*= operation. Read moreSourceimpl MulAssign for Seconds
impl MulAssign for Seconds
Sourcefn mul_assign(&mut self, other: Seconds)
fn mul_assign(&mut self, other: Seconds)
Performs the
*= operation. Read moreSourceimpl NumericValue for Seconds
impl NumericValue for Seconds
Sourcefn try_to_decimal(&self) -> Option<Decimal>
fn try_to_decimal(&self) -> Option<Decimal>
Convert this value into Decimal for generic numeric handling.
Sourcefn try_from_decimal(value: Decimal) -> Option<Self>
fn try_from_decimal(value: Decimal) -> Option<Self>
Rebuild the value from Decimal after generic numeric handling.
Sourceimpl Ord for Seconds
impl Ord for Seconds
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd<Seconds> for Nat64
impl PartialOrd<Seconds> for Nat64
Sourceimpl PartialOrd<u64> for Seconds
impl PartialOrd<u64> for Seconds
Sourceimpl PartialOrd for Seconds
impl PartialOrd for Seconds
Sourceimpl PersistedStructuredFieldCodec for Seconds
impl PersistedStructuredFieldCodec for Seconds
Sourcefn encode_persisted_structured_payload(&self) -> Result<Vec<u8>, InternalError>
fn encode_persisted_structured_payload(&self) -> Result<Vec<u8>, InternalError>
Encode this typed structured field into persisted structured payload bytes.
Sourcefn decode_persisted_structured_payload(
bytes: &[u8],
) -> Result<Self, InternalError>
fn decode_persisted_structured_payload( bytes: &[u8], ) -> Result<Self, InternalError>
Decode this typed structured field from persisted structured payload bytes.
Sourceimpl RuntimeValueDecode for Seconds
impl RuntimeValueDecode for Seconds
fn from_value(value: &Value) -> Option<Self>
Sourceimpl RuntimeValueMeta for Seconds
impl RuntimeValueMeta for Seconds
fn kind() -> RuntimeValueKind
Sourceimpl SanitizeAuto for Seconds
impl SanitizeAuto for Seconds
fn sanitize_self(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl SanitizeCustom for Seconds
impl SanitizeCustom for Seconds
fn sanitize_custom(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl SubAssign<u64> for Seconds
impl SubAssign<u64> for Seconds
Sourcefn sub_assign(&mut self, other: Nat64)
fn sub_assign(&mut self, other: Nat64)
Performs the
-= operation. Read moreSourceimpl SubAssign for Seconds
impl SubAssign for Seconds
Sourcefn sub_assign(&mut self, other: Seconds)
fn sub_assign(&mut self, other: Seconds)
Performs the
-= operation. Read moreSourceimpl ValidateAuto for Seconds
impl ValidateAuto for Seconds
fn validate_self(&self, _ctx: &mut dyn VisitorContext)
Sourceimpl ValidateCustom for Seconds
impl ValidateCustom for Seconds
fn validate_custom(&self, _ctx: &mut dyn VisitorContext)
Sourceimpl Visitable for Seconds
impl Visitable for Seconds
fn drive(&self, visitor: &mut dyn VisitorCore)
fn drive_mut(&mut self, visitor: &mut dyn VisitorMutCore)
impl Copy for Seconds
impl Eq for Seconds
impl StructuralPartialEq for Seconds