#[repr(transparent)]pub struct Url(pub Text);Tuple Fields
0: TextTrait Implementations
Sourceimpl CandidType for Url
impl CandidType for Url
Sourceimpl<'de> Deserialize<'de> for Url
impl<'de> Deserialize<'de> for Url
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FieldTypeMeta for Url
impl FieldTypeMeta for Url
Sourceconst KIND: FieldKind = Self::__KIND
const KIND: FieldKind = Self::__KIND
Semantic field kind used for runtime planning and validation.
Sourceconst STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
const STORAGE_DECODE: FieldStorageDecode = Self::__STORAGE_DECODE
Persisted decode contract used by row and payload decoding.
Sourceimpl FieldValue for Url
impl FieldValue for Url
Sourceimpl Ord for Url
impl Ord for Url
Sourceimpl PartialOrd<String> for Url
impl PartialOrd<String> for Url
Sourceimpl PartialOrd<Url> for Text
impl PartialOrd<Url> for Text
Sourceimpl PartialOrd for Url
impl PartialOrd for Url
Sourceimpl SanitizeAuto for Url
impl SanitizeAuto for Url
fn sanitize_self(&mut self, ctx: &mut dyn VisitorContext)
Sourceimpl SanitizeCustom for Url
impl SanitizeCustom for Url
fn sanitize_custom(&mut self, _ctx: &mut dyn VisitorContext)
Sourceimpl ValidateAuto for Url
impl ValidateAuto for Url
fn validate_self(&self, ctx: &mut dyn VisitorContext)
Sourceimpl ValidateCustom for Url
impl ValidateCustom for Url
fn validate_custom(&self, _ctx: &mut dyn VisitorContext)
Sourceimpl Visitable for Url
impl Visitable for Url
fn drive(&self, visitor: &mut dyn VisitorCore)
fn drive_mut(&mut self, visitor: &mut dyn VisitorMutCore)
impl Eq for Url
impl StructuralPartialEq for Url