pub struct WriteBatchResponse<E: EntityKind> { /* private fields */ }Expand description
WriteBatchResponse
Facade over batch write results with explicit accessors.
Implementations
Sourceimpl<E: EntityKind> WriteBatchResponse<E>
impl<E: EntityKind> WriteBatchResponse<E>
Sourcepub const fn new(entities: Vec<E>) -> Self
pub const fn new(entities: Vec<E>) -> Self
Construct a facade batch response from stored entities.
Sourcepub fn from_core(inner: CoreWriteBatchResponse<E>) -> Self
pub fn from_core(inner: CoreWriteBatchResponse<E>) -> Self
Construct a facade batch response from the core response.
Sourcepub fn ids(&self) -> impl Iterator<Item = Id<E>> + '_where
E: EntityValue,
pub fn ids(&self) -> impl Iterator<Item = Id<E>> + '_where
E: EntityValue,
Borrow an iterator over primary keys for correlation, reporting, and lookup.
Sourceimpl<E: EntityKind> WriteBatchResponse<E>
impl<E: EntityKind> WriteBatchResponse<E>