pub enum ErrorClass {
Conflict,
Corruption,
IncompatiblePersistedFormat,
Internal,
InvariantViolation,
NotFound,
Query,
Unsupported,
}Expand description
ErrorClass
Broad diagnostic class used for recovery decisions.
Variants
Conflict
Corruption
IncompatiblePersistedFormat
Internal
InvariantViolation
NotFound
Query
Unsupported
Implementations
Sourceimpl ErrorClass
impl ErrorClass
Sourcepub const fn wire_code(self) -> u8
pub const fn wire_code(self) -> u8
Return the compact public wire code for this diagnostic class.
Sourcepub const fn from_wire_code(code: u8) -> Option<ErrorClass>
pub const fn from_wire_code(code: u8) -> Option<ErrorClass>
Recover a diagnostic class from its compact public wire code.