Structs
- Error
- Error Public error type with a stable class + origin taxonomy.
Enums
- Error
Kind - ErrorKind Public error taxonomy for callers and canister interfaces.
- Error
Origin - ErrorOrigin Public origin taxonomy for callers and canister interfaces.
- Patch
Error - PatchError
- Query
Error Kind - QueryErrorKind
- Update
Error Kind - UpdateErrorKind