pub enum MergePatchError {
InvalidShape {
expected: &'static str,
actual: &'static str,
},
CardinalityViolation {
expected: usize,
actual: usize,
},
Context {
path: String,
source: Box<MergePatchError>,
},
}Expand description
MergePatchError
Structured failures for user-driven patch application.
Variants
Implementations
Sourceimpl MergePatchError
impl MergePatchError
Sourcepub fn with_field(self, field: impl AsRef<str>) -> MergePatchError
pub fn with_field(self, field: impl AsRef<str>) -> MergePatchError
Prepend a field segment to the merge error path.
Sourcepub fn with_index(self, index: usize) -> MergePatchError
pub fn with_index(self, index: usize) -> MergePatchError
Prepend an index segment to the merge error path.
Sourcepub fn leaf(&self) -> &MergePatchError
pub fn leaf(&self) -> &MergePatchError
Return the innermost, non-context merge error variant.