Account

Struct Account 

pub struct Account { /* private fields */ }

Implementations

Source

impl Account

pub const STORED_SIZE: u32 = 62

pub fn new<P, S>(owner: P, subaccount: Option<S>) -> Account
where P: Into<Principal>, S: Into<Subaccount>,

Build an account from owner and optional subaccount.

pub const fn from_parts( owner: Principal, subaccount: Option<Subaccount>, ) -> Account

Build an account from normalized runtime value parts.

pub const fn owner(&self) -> Principal

Return the account owner principal.

pub const fn subaccount(&self) -> Option<Subaccount>

Return the optional account subaccount.

pub fn to_icrc_type(self) -> Account

Convert to the ICRC account representation.

pub fn dummy(v: u8) -> Account

Test helper that builds a deterministic account from a byte seed.

pub fn to_bytes(self) -> Result<Vec<u8>, AccountEncodeError>

Convert the account into a deterministic, fixed-size byte representation.

pub fn max_storable() -> Account

Construct the maximum possible account for storage sizing tests.

pub fn try_from_bytes(bytes: &[u8]) -> Result<Account, &'static str>