pub struct Account { /* private fields */ }Implementations
Sourceimpl Account
impl Account
pub const STORED_SIZE: u32 = 62
Sourcepub fn new<P, S>(owner: P, subaccount: Option<S>) -> Account
pub fn new<P, S>(owner: P, subaccount: Option<S>) -> Account
Build an account from owner and optional subaccount.
Sourcepub const fn from_parts(
owner: Principal,
subaccount: Option<Subaccount>,
) -> Account
pub const fn from_parts( owner: Principal, subaccount: Option<Subaccount>, ) -> Account
Build an account from normalized runtime value parts.
Sourcepub const fn subaccount(&self) -> Option<Subaccount>
pub const fn subaccount(&self) -> Option<Subaccount>
Return the optional account subaccount.
Sourcepub fn to_icrc_type(self) -> Account
pub fn to_icrc_type(self) -> Account
Convert to the ICRC account representation.
Sourcepub fn dummy(v: u8) -> Account
pub fn dummy(v: u8) -> Account
Test helper that builds a deterministic account from a byte seed.
Sourcepub fn to_bytes(self) -> Result<Vec<u8>, AccountEncodeError>
pub fn to_bytes(self) -> Result<Vec<u8>, AccountEncodeError>
Convert the account into a deterministic, fixed-size byte representation.
Sourcepub fn max_storable() -> Account
pub fn max_storable() -> Account
Construct the maximum possible account for storage sizing tests.
pub fn try_from_bytes(bytes: &[u8]) -> Result<Account, &'static str>